css.href

# XMLRésuméLibrary: User Guide

address.format | XSL Parameter Reference | header.format

## Name

css.href — indicates the CSS stylesheet to use to format HTML output

## Applies To

This parameter applies to only the HTML output format.

## Possible Values

The value of `css.href` is a URL that points to a Cascading Style Sheet file. The HTML version of the résumé will link to this file.

For information on the CSS classes that are available for formatting, see Chapter 3.

address.format | XSL Parameter Reference | header.format